#ifndef __BDOC_PARSER_H__
#define __BDOC_PARSER_H__
//==================================================
// FILE:	DigiDocSAXParser.h
// PROJECT:     Digi Doc
// DESCRIPTION: Digi Doc functions for xml parsing using SAX interface
//              This is the older parser and will probably
//              be removed in new versions
// AUTHOR:  Ants Madisson, Business IT Partner
//==================================================
// Copyright (C) AS Sertifitseerimiskeskus
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// GNU Lesser General Public Licence is available at
// http://www.gnu.org/copyleft/lesser.html
//==========< HISTORY >=============================
//      25.02.2008      Ants Madisson
//                      Creation
//==================================================

#include <libdigidoc/DigiDocDefs.h>
#include <libdigidoc/DigiDocLib.h>

#ifdef  __cplusplus
extern "C" {
#endif


EXP_OPTION int addDataFileBDoc(SignedDoc* pSigDoc, char* filename, char* mime, char* ctype, int size, 
							   const char* dtype, byte* dvalue, int dlen,
							   byte* dvalue2, int dlen2);

//--------------------------------------------------
// Reads in signed XML document info from digidoc file
// ppSigDoc - pointer to the buffer of newly read info pointer
// szFileName - documents filename
// checkFileDigest - indicates if digests of datafiles referred by the document must be checked
// lMaxDFLen - maximum size for a DataFile whose contents will be
// kept in memory
//--------------------------------------------------
EXP_OPTION int bdocSaxReadSignedDocFromFile(SignedDoc** ppSigDoc, const char* szFileName, 
					    int checkFileDigest, long lMaxDFLen);

//--------------------------------------------------
// Reads in signed XML document and extracts the desired data file
// pSigDoc - signed document object if exists. Can be NULL
// szFileName - digidoc filename
// szDataFileName - name of the file where to store embedded data. 
// szDocId - DataFile Id atribute value
// szCharset - convert DataFile content to charset
//--------------------------------------------------
/*EXP_OPTION int ddocSaxExtractDataFile(SignedDoc* pSigDoc, const char* szFileName, const char* szDataFileName, 
				      const char* szDocId, const char* szCharset);*/

//--------------------------------------------------
// Reads in signed XML document and returns the
// desired DataFile-s content in a memory buffer.
// caller is responsible for freeing the memory.
// pSigDoc - signed document object if cached
// szFileName - name of digidoc file
// szDocId - id if DataFile
// pBuf - address of buffer pointer
// bKeepBase64 - 1=don't decode base64, 0=decode base64
// returns error code or ERR_OK
//--------------------------------------------------
/*EXP_OPTION int ddocSAXGetDataFile(SignedDoc* pSigDoc, const char* szFileName,
				  const char* szDocId, DigiDocMemBuf* pBuf,
				  int bKeepBase64);*/

//--------------------------------------------------
// Reads in signed XML document info from memory buffer
// ppSigDoc - pointer to the buffer of newly read info pointer
// szFileName - documents filename
// checkFileDigest - indicates if digests of datafiles referred by the document must be checked
// lMaxDFLen - maximum size for a DataFile whose contents will be
// kept in memory
//--------------------------------------------------
EXP_OPTION int bdocSaxReadSignedDocFromMemory(SignedDoc** ppSigDoc, const void* pData, 
					      int len, long lMaxDFLen);

//--------------------------------------------------
// Reads new signatures from another digidoc file
// and adds to existing digidoc. Adds only those
// signatures that don't exist in old digidoc.
// pSigDoc - signed document object
// szFileName - name of digidoc file
// returns error code or ERR_OK
//--------------------------------------------------
EXP_OPTION int bdocReadNewSignaturesFromDdoc(SignedDoc* pSigDoc, const char* szFileName);

EXP_OPTION int bdocExtractDataFile(const char* szFileName, const char* szDataFileNameInZip, const char* szDataFileName);

EXP_OPTION int bdocGetDataFile(const char* szFileName, const char* szDataFileNameInZip, DigiDocMemBuf* pBuf);

#ifdef  __cplusplus
}
#endif


#endif // __BDOC_PARSER_H__

